@@ -17,11 +17,27 @@ CONFIG_NAME = '.quera_config'
 
 @cached
 def __get_current_file_id():
-    try:
-        response = requests.get('http://172.28.0.2:9000/api/sessions').json()
-    except requests.exceptions.JSONDecodeError:
+    p: str = subprocess.run('ps -aux | grep "\-\-ip=\S*"', shell=True, stdout=subprocess.PIPE).stdout.strip().decode()
+    if '--port' not in p and '--ip' not in p:
         print('Colab Error: please call quera support; colab api session is not working.')
         return None
+
+    output = p.split()
+
+    def get_flag(flag_name):
+        data = next(filter(lambda x: x.startswith(f'--{flag_name}='), output), None)
+        if not data:
+            raise Exception(f'Colab Error: please call quera support; colab api session has no "{flag_name}" flag.')
+        return data.split('=')[1]
+
+    ip, port = get_flag('ip'), get_flag('port')
+    try:
+        response = requests.get(f'http://{ip}:{port}/api/sessions').json()
+    except Exception as e:
+        print('Colab Error: please call quera support; colab api session is not working.')
+        print(e)
+        return None
+
     if len(response) > 0 and 'path' in response[0] and 'fileId=' in response[0]['path']:
         _file_id = response[0]['path'].split('=', 1)[1]
         return urllib.parse.unquote(_file_id)
